@@ -1,7 +1,8 @@
-use pkgcraft::test::cmd;
 use predicates::prelude::*;
 use predicates::str::contains;
 
+use crate::cmd;
+
 #[test]
 fn args() {
     // intersect
