@@ -13,7 +13,7 @@ macro_rules! cmd_arg_tests {
             let dir = tempfile::tempdir().unwrap();
             std::env::set_current_dir(dir.path()).unwrap();
             let s = "invalid ebuild repo: .";
-            pkgcraft::test::cmd($cmd)
+            $crate::cmd($cmd)
                 .assert()
                 .stdout("")
                 .stderr(predicates::str::contains(s))
@@ -25,7 +25,7 @@ macro_rules! cmd_arg_tests {
             let repo = "path/to/nonexistent/repo";
             let cmd = format!("{} {repo}", $cmd);
             let s = format!("invalid path target: {repo}: No such file or directory");
-            pkgcraft::test::cmd(cmd)
+            $crate::cmd(cmd)
                 .assert()
                 .stdout("")
                 .stderr(predicates::str::contains(s))
@@ -36,7 +36,7 @@ macro_rules! cmd_arg_tests {
         fn empty_repo() {
             let data = pkgcraft::test::test_data();
             let repo = data.ebuild_repo("empty").unwrap();
-            pkgcraft::test::cmd($cmd)
+            $crate::cmd($cmd)
                 .arg(repo)
                 .assert()
                 .stdout("")
@@ -48,7 +48,7 @@ macro_rules! cmd_arg_tests {
         fn no_matches() {
             // no repos
             let s = "no repos available";
-            pkgcraft::test::cmd($cmd)
+            $crate::cmd($cmd)
                 .arg("cat/pkg")
                 .assert()
                 .stdout("")
@@ -61,7 +61,7 @@ macro_rules! cmd_arg_tests {
 
             // Cpn target
             let s = "no matches found: cat/pkg";
-            pkgcraft::test::cmd($cmd)
+            $crate::cmd($cmd)
                 .args(["-r", repo.path().as_str()])
                 .arg("cat/pkg")
                 .assert()
@@ -72,7 +72,7 @@ macro_rules! cmd_arg_tests {
 
             // category target
             let s = "no matches found: category";
-            pkgcraft::test::cmd($cmd)
+            $crate::cmd($cmd)
                 .args(["-r", repo.path().as_str()])
                 .arg("category")
                 .assert()
