@@ -1,8 +1,10 @@
 use std::env;
 
-use pkgcraft::test::{cmd, test_data};
+use pkgcraft::test::test_data;
 use predicates::prelude::*;
 
+use crate::cmd;
+
 super::cmd_arg_tests!("pk pkg env");
 
 #[test]
