@@ -2,7 +2,7 @@ use std::time::Duration;
 use std::{env, fs};
 
 use pkgcraft::repo::ebuild::EbuildRepoBuilder;
-use pkgcraft::test::{cmd, test_data};
+use pkgcraft::test::test_data;
 use predicates::prelude::*;
 use predicates::str::contains;
 use pretty_assertions::assert_eq;
@@ -10,6 +10,8 @@ use tempfile::tempdir;
 use wiremock::matchers::{method, path, query_param};
 use wiremock::{Mock, MockServer, ResponseTemplate};
 
+use crate::cmd;
+
 super::cmd_arg_tests!("pk pkg fetch");
 
 #[test]
