@@ -4,7 +4,7 @@ use std::{env, fs};
 use pkgcraft::config::Config;
 use pkgcraft::pkg::ebuild::manifest::HashType;
 use pkgcraft::repo::ebuild::EbuildRepoBuilder;
-use pkgcraft::test::{cmd, test_data};
+use pkgcraft::test::test_data;
 use predicates::prelude::*;
 use predicates::str::contains;
 use pretty_assertions::assert_eq;
@@ -12,6 +12,8 @@ use tempfile::tempdir;
 use wiremock::matchers::{method, path, query_param};
 use wiremock::{Mock, MockServer, ResponseTemplate};
 
+use crate::cmd;
+
 super::cmd_arg_tests!("pk pkg manifest");
 
 #[test]
