@@ -2,11 +2,13 @@ use std::env;
 
 use pkgcraft::repo::Repository;
 use pkgcraft::repo::ebuild::EbuildRepoBuilder;
-use pkgcraft::test::{cmd, test_data};
+use pkgcraft::test::test_data;
 use predicates::prelude::*;
 use predicates::str::contains;
 use tempfile::tempdir;
 
+use crate::cmd;
+
 #[test]
 fn nonexistent_repo() {
     cmd("pk repo leaf path/to/nonexistent/repo")
