@@ -3,10 +3,11 @@ use std::env;
 use pkgcraft::config::Config;
 use pkgcraft::repo::ebuild::EbuildRepoBuilder;
 use pkgcraft::repo::ebuild::cache::Cache;
-use pkgcraft::test::cmd;
 use predicates::str::contains;
 use tempfile::tempdir;
 
+use crate::cmd;
+
 #[test]
 fn run() {
     let mut config = Config::default();
