@@ -1,6 +1,7 @@
-use pkgcraft::test::cmd;
 use predicates::prelude::*;
 
+use crate::cmd;
+
 #[test]
 fn args() {
     // intersect
