@@ -1,7 +1,9 @@
 use itertools::Itertools;
-use pkgcraft::test::{cmd, test_data};
+use pkgcraft::test::test_data;
 use predicates::prelude::*;
 
+use crate::cmd;
+
 #[test]
 fn valid() {
     let data = test_data();
