@@ -1,4 +1,6 @@
-use pkgcraft::test::{cmd, test_data};
+use pkgcraft::test::test_data;
+
+use crate::cmd;
 
 #[test]
 fn stdin() {
